@@ -5,7 +5,6 @@ from collections import OrderedDict
 import pandas as pd
 import pytest
 from numpy.testing import assert_array_equal
-from pandas.testing import assert_frame_equal
 
 from powersimdata.data_access.data_access import LocalDataAccess, SSHDataAccess
 from powersimdata.data_access.execute_list import ExecuteListManager
@@ -23,14 +22,6 @@ def execute_table(data_access):
     return execute_list_manager.get_execute_table()
 
 
-@pytest.mark.integration
-@pytest.mark.ssh
-def test_get_execute_file_local(execute_table):
-    ecm = ExecuteListManager(None)
-    from_local = ecm.get_execute_table()
-    assert_frame_equal(from_local, execute_table)
-
-
 @pytest.mark.integration
 @pytest.mark.ssh
 def test_get_execute_file_from_server_type(execute_table):
